@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * Copyright (c) 2000, 2001, 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005 BalaBit IT Ltd, Budapest, Hungary
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -250,7 +250,7 @@ z_attach_start(ZAttach *self)
         self->c.connect = z_io_connect_new(self->session_id, self->bind_addr, self->remote, (self->params.tcp.loose ? ZSF_LOOSE_BIND : 0) | ZSF_MARK_TPROXY, self->params.tcp.tos, z_attach_tcp_callback, self);
         if (self->c.connect)
           {
-            z_io_connect_set_timeout(self->c.connect, self->params.tcp.timeout);
+            z_io_connect_set_timeout(self->c.connect, self->params.tcp.timeout < 0 ? -1 : (self->params.tcp.timeout + 999) / 1000);
             z_attach_ref(self);
             z_io_connect_set_destroy_notify(self->c.connect, (GDestroyNotify) z_attach_unref);
             if (self->callback)
