@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * Copyright (c) 2000, 2001, 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005 BalaBit IT Ltd, Budapest, Hungary
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -191,7 +191,7 @@ z_l22_packsock_recv(gint fd, ZPacket **packet,
 
   do
     {                
-      rc = recvmsg(fd, &msg, MSG_PROXY);
+      rc = recvmsg(fd, &msg, MSG_PROXY | MSG_DONTWAIT);
       
     }
   while (rc < 0 && errno == EINTR);
@@ -299,7 +299,7 @@ z_l22_packsock_read(gint fd, ZPacket **packet, GError **error G_GNUC_UNUSED)
   
   do
     {
-      rc = recv(fd, buf, sizeof(buf), 0);
+      rc = recv(fd, buf, sizeof(buf), MSG_DONTWAIT);
     }
   while (rc < 0 && errno == EINTR);
   
@@ -568,7 +568,7 @@ z_nf_packsock_recv(gint fd, ZPacket **packet, ZSockAddr **from_addr, ZSockAddr *
                 
   do
     {
-      rc = recvmsg(fd, &msg, 0);
+      rc = recvmsg(fd, &msg, MSG_DONTWAIT);
     }
   while (rc < 0 && errno == EINTR);
   
@@ -683,7 +683,7 @@ z_nf_packsock_read(gint fd, ZPacket **packet, GError **error G_GNUC_UNUSED)
   
   do
     {
-      rc = recv(fd, buf, sizeof(buf), 0);
+      rc = recv(fd, buf, sizeof(buf), MSG_DONTWAIT);
     }
   while (rc < 0 && errno == EINTR);
   
