@@ -500,7 +500,7 @@ z_py_zorp_method_call(ZorpMethod *self, PyObject *args, PyObject *kw G_GNUC_UNUS
 static void
 z_py_zorp_method_free(ZorpMethod *self)
 {
-  PyMem_DEL(self);
+  PyObject_Del(self);
 }
 
 PyTypeObject z_py_zorp_method_type = 
@@ -625,7 +625,7 @@ z_py_zorp_hash_free(ZorpHash *self)
 {
   g_hash_table_foreach_remove(self->hash, z_py_zorp_hash_unref_items, NULL);
   g_hash_table_destroy(self->hash);
-  PyMem_DEL(self);
+  PyObject_Del(self);
 }
 
 /**
@@ -830,7 +830,7 @@ static void
 z_py_zorp_dimhash_free(ZorpDimHash *self)
 {
   z_dim_hash_table_free(self->hash, z_py_zorp_dimhash_unref_items);
-  PyMem_DEL(self);
+  PyObject_Del(self);
 }
 
 /**
