@@ -302,7 +302,7 @@ z_py_zorp_attach_free(ZorpAttach *self)
     }
   z_sockaddr_unref(self->local);
 
-  PyMem_DEL(self);
+  PyObject_Del(self);
   z_leave();
 }
 
