@@ -365,7 +365,7 @@ z_py_zorp_dispatch_free(ZorpDispatch *self)
       Py_END_ALLOW_THREADS;
       self->policy_thread = NULL;
     }
-  PyMem_DEL(self);
+  PyObject_Del(self);
 }
 
 /**
