@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * Copyright (c) 2000, 2001, 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005 BalaBit IT Ltd, Budapest, Hungary
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -257,13 +257,17 @@ z_fp_connect_chainer_chain(ZProxyFastpathSession *session, gpointer data)
   ZStream *stream = NULL;
   ZConnection *new_conn;
   
+  memset(&params, 0, sizeof(params));
+  
   switch (self->protocol)
     {
     case ZD_PROTO_TCP:
-      params.tcp.timeout = 30;
+      params.tcp.timeout = 30000;
+      params.tcp.tos = -1;
       break;
 #if ENABLE_CONNTRACK
     case ZD_PROTO_UDP:
+      params.udp.tos = -1;
       break;
 #endif
     }
