@@ -173,7 +173,7 @@ z_py_zorp_proxy_free(ZorpProxy *self)
 {
   if (self->proxy)
     z_proxy_unref(self->proxy);
-  PyMem_DEL(self);
+  PyObject_Del(self);
 }
 
 
