@@ -460,7 +460,7 @@ static void
 z_py_zorp_sockaddr_free(ZorpSockAddr *self)
 {
   z_sockaddr_unref(self->sa);
-  PyMem_DEL(self);
+  PyObject_Del(self);
 }
 
 
