@@ -3,7 +3,7 @@
  * Copyright (c) 2000, 2001, 2002 BalaBit IT Ltd, Budapest, Hungary
  * All rights reserved.
  *
- * $Id: tpsocket.h,v 1.3.2.4 2003/09/17 13:16:01 sasa Exp $
+ * $Id: tpsocket.h,v 1.8 2004/02/18 09:05:29 sasa Exp $
  *
  * Author  : Bazsi
  * Auditor :
@@ -20,6 +20,13 @@
 extern const gchar *auto_bind_ip;
 
 gboolean z_tp_socket_init(gint sysdep_tproxy);
-gint z_tp_autobind(gint fd);
+
+int z_tp_assign(int fd, in_addr_t faddr, guint16 fport);
+int z_tp_set_flags(int fd, int flags);
+int z_tp_get_flags(int fd, int *flags);
+int z_tp_connect(int fd, in_addr_t faddr, guint16 fport);
+int z_tp_query(int fd, in_addr_t *faddr, guint16 *fport);
+int z_tp_alloc(int fd);
+
 
 #endif
