@@ -1,6 +1,6 @@
 ############################################################################
 ##
-## Copyright (c) 2000, 2001, 2002 BalaBit IT Ltd, Budapest, Hungary
+## Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005 BalaBit IT Ltd, Budapest, Hungary
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -94,7 +94,7 @@ class FtpDataProxy(PlugProxy):
 			self.shutdown_soft = TRUE
 			self.stack_proxy = self.session.ftp_stack
 
-	def __destroy__(self):
+	def __pre_shutdown__(self):
 		"""Function called when the session is terminated.
 		
 		We call the registered stop() function to indicate the end
@@ -104,11 +104,7 @@ class FtpDataProxy(PlugProxy):
 		
 		  self -- this instance
 		"""
-		PlugProxy.__destroy__(self)
-		try:
-			self.session.ftp_data_stop()
-		except:
-			pass
+		self.session.ftp_data_stop()
 
 class AbstractFtpProxy(Proxy):
 	"""Class encapsulating the FTP proxy implemented in Zorp.
@@ -823,6 +819,7 @@ class FtpProxyAnonRO(AbstractFtpProxy):
 	def pUser(self,command):
 		if self.request_parameter == "ftp" or self.request_parameter == "anonymous":
 			return FTP_REQ_ACCEPT
+		proxyLog(self, FTP_POLICY, 3, "Non-anonymous user rejected; user='%s'", (self.request_parameter,))
 		return FTP_REQ_REJECT
 
 	def config(self):
@@ -888,6 +885,7 @@ class FtpProxyAnonRW(AbstractFtpProxy):
 	def pUser(self,command):
 		if self.request_parameter == "ftp" or self.request_parameter == "anonymous":
 			return FTP_REQ_ACCEPT
+		proxyLog(self, FTP_POLICY, 3, "Non-anonymous user rejected; user='%s'", (self.request_parameter,))
 		return FTP_REQ_REJECT
 
 	def config(self):
