@@ -1,6 +1,6 @@
 ############################################################################
 ##
-## Copyright (c) 2000, 2001, 2002 BalaBit IT Ltd, Budapest, Hungary
+## Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005 BalaBit IT Ltd, Budapest, Hungary
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -359,7 +359,7 @@ class AbstractHttpProxy(Proxy):
 
 	    It is generally advisably not to display error messages to
 	    untrusted clients, as they may leak confidental information. To
-	    turn error messages off, set 'error_silent' to 'FALSE', or 
+	    turn error messages off, set 'error_silent' to 'TRUE', or 
 	    strip error files down to a minimum.
 
 	Stacking
@@ -505,9 +505,10 @@ class AbstractHttpProxy(Proxy):
 	  max_body_length             -- [INTEGER:0:RW:RW] maximum length 
 					 of an HTTP request or response body.
 
-          max_chunk_length	      -- [INTEGER:262144:RW:RW] maximum
-                                         length of a single chunk when 
-                                         using chunked transfer-encoding.
+          max_chunk_length	      -- [INTEGER:0:RW:RW] maximum length of
+                                         a single chunk when using chunked
+                                         transfer-encoding. (0 means
+                                         unlimited)
 
 	  max_header_lines	      -- [INTEGER:50:RW:RW] maximum number of
 	                                 header lines in a request or
