@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * Copyright (c) 2000, 2001, 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005 BalaBit IT Ltd, Budapest, Hungary
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -459,8 +459,11 @@ http_transfer_dst_write_preamble(HttpTransfer *self, ZStream *stream, GError **e
           res = G_IO_STATUS_AGAIN;
         }
     }
-  else if (g_error_matches(local_error, G_IO_CHANNEL_ERROR, G_IO_CHANNEL_ERROR_PIPE))
+  else if (self->src_read_state == HTTP_SR_INITIAL && g_error_matches(local_error, G_IO_CHANNEL_ERROR, G_IO_CHANNEL_ERROR_PIPE))
     {
+      /* we can only reattempt a connection if nothing was read from the
+       * client, that's the reason behind src_read_state == INITIAL above */
+      
       /* FIXME: this is a hack. A better solution would be to propagate
        * GError to the proxy so this case can be handled there cleanly */
        
@@ -1118,20 +1121,28 @@ http_data_transfer(HttpProxy *self, guint from, ZStream *from_stream, guint to,
   else
     {
       /* transfer was successful, check if the stacked proxy told us something important */
-      switch (self->stack_decision)
+      if (self->stack_decision != Z_ACCEPT)
         {
-        case Z_REJECT:
-	  /*LOG
-	    This message indicates that the stacked proxy rejected the
-	    content. Check the stacked proxy log for further information.
-	   */
-          z_proxy_log(self, HTTP_ERROR, 2, "Stacked proxy rejected contents; info='%s'", self->stack_info->str);
-          g_string_assign(self->error_info, self->stack_info->str);
-          break;
-        default:
-          /* nothing was received */
-          break;
+          /*LOG
+            This message indicates that the stacked proxy returned the
+            specified verdict about the content. Check the stacked proxy log
+            for further information.
+           */
+          z_proxy_log(self, HTTP_ERROR, 2, "Stacked proxy decision; verdict='%d', info='%s'", self->stack_decision, self->stack_info->str);
+          if (self->stack_info->len)
+            g_string_assign(self->error_info, self->stack_info->str);
+          else
+            g_string_sprintf(self->error_info, "Stacked proxy did not accept this content (%d).", self->stack_decision);
         }
+      else
+        {
+          /*LOG
+            This message indicates that the stacked proxy accepted the
+            content. 
+           */
+          z_proxy_log(self, HTTP_DEBUG, 6, "Stacked proxy accepted data;");
+        }
+      
     }
 
   if (t->super.status & ZTS_HTTP_TRANSFER_DELAYED)
