@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * Copyright (c) 2000, 2001, 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005 BalaBit IT Ltd, Budapest, Hungary
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -390,7 +390,7 @@
 #define DONT_OPTION             4
 
 #define TELNET_BUFFER_SIZE      1024
-#define TELNET_SUBOPTION_SIZE   TELNET_BUFFER_SIZE
+#define TELNET_SUBOPTION_SIZE   (TELNET_BUFFER_SIZE - 4) /* IAC SB code + 1 byte */
 
 #define TELNET_CHECK_OK         1
 #define TELNET_CHECK_REJECT     3
@@ -408,7 +408,7 @@
 #define OTHER_EP(x)             ((EP_MAX - 1) - x)
 
 /* macro to convert endpoint number to string */
-#define WHICH_EP(x)             ((x) ? "client" : "server")
+#define WHICH_EP(x)             (((x) == EP_CLIENT) ? "client" : "server")
 
 struct _TelnetProxy;
 
