@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * Copyright (c) 2000, 2001, 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005 BalaBit IT Ltd, Budapest, Hungary
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -430,7 +430,7 @@ telnet_opt_new_env(TelnetProxy *self, guint ep)
                       break; /* switch */
                     }
                 }
-              z_proxy_log(self, TELNET_DEBUG, 6, "NEW-ENVIRON %s; name='%s', value='%s'",
+              z_proxy_log(self, TELNET_DEBUG, 6, "NEW-ENVIRON; subopt='%s', name='%s', value='%s'",
                           (command == TELNET_SB_ENVIRONMENT_IS) ? "IS" : "INFO", name, value);
 
               g_string_assign(self->policy_name, name);
