@@ -10,8 +10,8 @@ def test(str, res, expect):
 	if res != expect:
 		print str, 'failed,', res, 'should be: ', expect
 		raise 'test error'
-	#else:
-	#	print str, 'ok,', res
+	else:
+		print str, 'ok,', res
 
 def init(name):
 	try:
@@ -24,6 +24,10 @@ def init(name):
 		t7 = InetZone("test7", "192.168.0.0/16")
 		t8 = InetZone("test8", "192.168.1.1/32", admin_parent="test1")
 		t9 = InetZone("test9", "192.168.1.2/32", admin_parent="test8")
+		t10 = InetZone("test10", "192.168.1.3/32", admin_parent="test9", umbrella=1)
+		t11 = InetZone("test11", "192.168.1.4/32", admin_parent="test9")
+		t12 = InetZone("test12", "192.168.1.5/32", inbound_services=['*'])
+		t13 = InetZone("test13", "192.168.1.6/32", outbound_services=['*'])
 		
 		test('192.168.0.1', root_zone.findZone(SockAddrInet('192.168.0.1', 10)), t3)
 		test('192.168.0.33', root_zone.findZone(SockAddrInet('192.168.0.33', 10)), t2)
@@ -31,6 +35,7 @@ def init(name):
 		test('192.168.0.97', root_zone.findZone(SockAddrInet('192.168.0.97', 10)), t5)
 		test('192.168.0.129', root_zone.findZone(SockAddrInet('192.168.0.129', 10)), t1)
 		test('192.168.1.129', root_zone.findZone(SockAddrInet('192.168.1.129', 10)), t7)
+
 		inet = InetZone("internet", "0.0.0.0/0", inbound_services=["s2"], outbound_services=["s1"])
 		test('1.1.1.1', root_zone.findZone(SockAddrInet('1.1.1.1', 10)), inet)
 		#for i in range(1,100):
@@ -51,11 +56,37 @@ def init(name):
 		test('service s1#2', t1.isOutboundServicePermitted(s), Z_REJECT)
 		test('service s1#3', inet.isInboundServicePermitted(s), Z_REJECT)
 		test('service s1#4', inet.isOutboundServicePermitted(s), Z_ACCEPT)
+		###
+		test('service s1#5', t10.isOutboundServicePermitted(s), Z_REJECT)
+		test('service s1#6', t10.isInboundServicePermitted(s), Z_REJECT)
+		
+		test('service s1#7', t11.isOutboundServicePermitted(s), Z_REJECT)
+		test('service s1#8', t11.isInboundServicePermitted(s), Z_ACCEPT)
+
+		test('service s1#9', t12.isInboundServicePermitted(s), Z_ACCEPT)
+		test('service s1#10', t12.isOutboundServicePermitted(s), Z_REJECT)
+
+		test('service s1#11', t13.isOutboundServicePermitted(s), Z_ACCEPT)
+		test('service s1#12', t13.isInboundServicePermitted(s), Z_REJECT)
+		
+		
 		s.service = Service("s2", None)
 		test('service s2#1', t1.isInboundServicePermitted(s), Z_REJECT)
 		test('service s2#2', t1.isOutboundServicePermitted(s), Z_ACCEPT)
 		test('service s2#3', inet.isInboundServicePermitted(s), Z_ACCEPT)
 		test('service s2#4', inet.isOutboundServicePermitted(s), Z_REJECT)
+		###
+		test('service s2#5', t10.isInboundServicePermitted(s), Z_REJECT)
+		test('service s2#6', t10.isOutboundServicePermitted(s), Z_REJECT)
+
+		test('service s2#7', t11.isOutboundServicePermitted(s), Z_ACCEPT)
+		test('service s2#8', t11.isInboundServicePermitted(s), Z_REJECT)
+
+		test('service s2#9', t12.isInboundServicePermitted(s), Z_ACCEPT)
+		test('service s2#10', t12.isOutboundServicePermitted(s), Z_REJECT)
+
+		test('service s2#11', t13.isOutboundServicePermitted(s), Z_ACCEPT)
+		test('service s2#12', t13.isInboundServicePermitted(s), Z_REJECT)
 
 	except Exception, e:
 		print_exc()
