@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * Copyright (c) 2000, 2001, 2002, 2003, 2004 BalaBit IT Ltd, Budapest, Hungary
+ * Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005 BalaBit IT Ltd, Budapest, Hungary
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -949,7 +949,7 @@ z_process_stop_instance(ZInstance *inst, void *user_data)
         }
       if (!killed)
         {
-          z_error(0, "Cannot kill Zorp (instance='%s', signo=%d) ", SAFE_STR(inst->name), signo);
+          z_error(1, "Zorp instance did not exit in time (instance='%s', pid='%d', signo='%d', timeout='%d')\n", SAFE_STR(inst->name), pid, signo, stop_check_timeout);
           return 0;
         }
       if (signo == SIGKILL)
